@@ -1,7 +1,6 @@
 import datetime
 
 from django.core.exceptions import FieldDoesNotExist
-from django.db.models import IntegerField
 from django.template.loader import render_to_string
 from django.utils.safestring import mark_safe
 from django_datatables.datatables import DatatableTable
@@ -13,6 +12,7 @@ CARD_TYPE_STANDARD = 1
 CARD_TYPE_DATATABLE = 2
 CARD_TYPE_ORDERED_DATATABLE = 3
 CARD_TYPE_HTML = 4
+CARD_TYPE_LIST_SELECTION = 5
 
 
 class CardBase:
@@ -28,16 +28,28 @@ class CardBase:
                                            'card_body_css_class': 'card-body cards-list'}},
                  'html': {'name': 'cards/standard/html.html',
                           'context': {'card_css_class': 'card django-card',
-                                      'card_body_css_class': 'card-body cards-list'}}}
+                                      'card_body_css_class': 'card-body cards-list'}},
+                 'list_selection': {'name': 'cards/standard/list_selection.html',
+                                    'context': {'card_css_class': 'card django-card',
+                                                'card_body_css_class': 'card-body cards-list'}},
+                 'tree_selection': {'name': 'cards/standard/tree_selection.html',
+                                    'context': {'card_css_class': 'card django-card',
+                                                'card_body_css_class': 'card-body cards-list'}},
+                 'blank': {'name': 'cards/standard/blank.html'}}
 
     ajax_commands = ['datatable']
 
     template_defaults = {CARD_TYPE_STANDARD: 'default',
                          CARD_TYPE_DATATABLE: 'datatable',
                          CARD_TYPE_ORDERED_DATATABLE: 'datatable',
-                         CARD_TYPE_HTML: 'html'}
+                         CARD_TYPE_HTML: 'html',
+                         CARD_TYPE_LIST_SELECTION: 'list_selection'}
 
-    def __init__(self, request, code, view=None, details_object=None, title=None, menu=None, template_name=None,
+    button_menu_type = 'button_group'
+    tab_menu_type = 'tabs'
+
+    def __init__(self, request, code, view=None, details_object=None, title=None,
+                 menu=None, tab_menu=None, template_name=None,
                  group_type=CARD_TYPE_STANDARD, show_created_modified_dates=False,
                  footer=None, extra_card_context=None, **kwargs):
 
@@ -53,9 +65,12 @@ class CardBase:
         self.title = title
         self.created_modified_dates = self.get_created_modified_dates(details_object=details_object)
         if isinstance(menu, (list, tuple)):
-            menu = HtmlMenu(self.request, 'button_group').add_items(*menu)
-
+            menu = HtmlMenu(self.request, self.button_menu_type).add_items(*menu)
         self.menu = menu
+        if isinstance(tab_menu, (list, tuple)):
+            tab_menu = HtmlMenu(self.request, self.tab_menu_type).add_items(*tab_menu)
+        self.tab_menu = tab_menu
+
         self.extra_card_context = extra_card_context
         self.template_name = template_name
         self.extra_card_info = {}
@@ -288,6 +303,8 @@ class CardBase:
                     setup_table_field = field_setup_table_field
 
             getattr(self.view, setup_table_field)(details_object=self.details_object, table=table)
+            if hasattr(self.view, 'tables'):
+                self.view.tables[self.code] = table
 
     def add_table(self, model, table_id=None):
         table = DatatableTable(table_id=table_id, model=model, view=self.view)
